package org.sonatype.plexus.jetty;

import java.io.File;
import java.io.IOException;

import org.codehaus.plexus.classworlds.ClassWorld;
import org.codehaus.plexus.interpolation.InterpolationException;
import org.tanukisoftware.wrapper.WrapperManager;

/**
 * Class extending Jetty7 and adding Java Service Wrapper support on it, making Jetty7 "jsw-ized". This class is used as
 * "main" launched class in Nexus bundle (JSW launches ClassWorlds, that launches this). Requirement for App is to have
 * path to jetty.xml passed as first argument.
 * 
 * @author cstamas
 */
public class Jetty7CWEnhancedWrapperListener
    extends Jetty7WrapperListener
{
    protected Jetty7CWEnhancedWrapperListener( final File jettyXml )
        throws InterpolationException, IOException
    {
        // nope, do not instantiate this directly, just from main()!
        super( jettyXml );
    }

    /**
     * "Standard" main method, starts embedded Jetty "by the book", and it returns.
     * 
     * @param args
     * @throws IOException
     * @throws InterpolationException
     */
    public static void main( final String[] args )
        throws InterpolationException, IOException
    {
        if ( args != null && args.length > 0 )
        {
            final File jettyXml = new File( args[0] );

            WrapperManager.start( new Jetty7CWEnhancedWrapperListener( jettyXml ), args );
        }
        else
        {
            WrapperManager.log( WrapperManager.WRAPPER_LOG_LEVEL_FATAL,
                "First supplied app parameter should be path to existing jetty7 XML configuration file!" );

            WrapperManager.stop( 1 );
        }
    }

    /**
     * "Enhanced" main method, used by Plexus ClassWorlds, that starts Jetty but also blocks until it's stopped. It has
     * to block, since ClassWorlds Launcher class would issue System.exit() upon return from this method.
     * 
     * @param args
     * @param world
     * @throws IOException
     * @throws InterpolationException
     */
    public static void main( final String[] args, final ClassWorld world )
        throws InterpolationException, IOException
    {
        // Note: it seems the WrapperManager.log does not work until WrapperManager.start is invoked
        // Hence, this line below will NOT appear, but it is invoked, honest!
        WrapperManager.log( WrapperManager.WRAPPER_LOG_LEVEL_INFO,
            "Started using Classworld \"enhanced\" main method..." );

        main( args );

        // because of stupid ClassWorlds Launcher, we need NOT to exit
        // now wait forever.
        try
        {
            synchronized ( waitObj )
            {
                waitObj.wait();
            }
        }
        catch ( InterruptedException e )
        {
        }
    }
}
